@@ -1,5 +1,3 @@
-# Intra-package dependencies
-from .User import User
 # General Imports
 import mysql.connector
 from mysql.connector import errorcode
@@ -106,15 +104,19 @@ class Database:
             self.connection = None
 
     def reconnect(self):
-        if "user" in dir(self) and "password" in dir(self):
-            if self.auth_plugin:
-                self.connect(user=self.user, password=self.password, auth_plugin=self.auth_plugin, nolog=True, log_level = self.log_level)
-            else:
-                self.connect(user=self.user, password=self.password, nolog=True, log_level = self.log_level)
+        try:
+            self.connection.ping(reconnect=True, attempts=3, delay=5)
+        except:
+            if "user" in dir(self) and "password" in dir(self):
+                if self.auth_plugin:
+                    self.connect(user=self.user, password=self.password, auth_plugin=self.auth_plugin, nolog=True, log_level = self.log_level)
+                else:
+                    self.connect(user=self.user, password=self.password, nolog=True, log_level = self.log_level)
 
     # Execute single command
     def execute(self,command):
-        self.reconnect()
+        if not self.is_connected():
+            self.connection.ping(reconnect=True, attempts=3, delay=5)
         resultset = {
             'rows': []
         }
@@ -226,6 +228,8 @@ class Database:
 
     ## User Methods
     def get_users(self):
+        from pyoomysql.User import User
+
         response = []
         result = self.execute(f"SELECT user, host FROM mysql.user")
         if len(result["rows"]) > 0:
@@ -237,6 +241,7 @@ class Database:
         return response
 
     def get_user_by_name(self, user):
+        from pyoomysql.User import User
         response = []
         result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}'")
         if len(result["rows"]) > 0:
@@ -248,6 +253,7 @@ class Database:
         return response
 
     def get_user_by_name_host(self, user, host):
+        from pyoomysql.User import User
         result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}' AND host = '{host}'")
         if result["rowcount"] == 1:
             if type(result["rows"][0]["user"]) is bytearray:
@@ -299,7 +305,7 @@ class Database:
 
     # Check if there's an active connection to the database
     def is_connected(self):
-        if self.connection:
+        if self.connection.is_connected():
             return True
         else:
             return False
